@@ -4,7 +4,7 @@
 modname = "cubicweb_file"
 distname = "cubicweb-file"
 
-numversion = (3, 2, 0)
+numversion = (3, 5, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -20,7 +20,7 @@ classifiers = [
 ]
 
 __depends__ = {
-    "cubicweb": ">= 3.27, < 3.37.0",
+    "cubicweb": ">= 3.38.0, < 3.39.0",
     "Pillow": None,
 }
 
