@@ -12,7 +12,6 @@ import os
 from os.path import join, splitext, exists, isfile, isabs
 
 from PIL.Image import open as pilopen
-from PIL.Image import ANTIALIAS
 
 from logilab.mtconverter import guess_mimetype_and_encoding
 from logilab.common.deprecation import callable_deprecated
@@ -43,6 +42,16 @@ class File(AnyEntity):
             old, new = self.cw_edited.oldnewvalue("data_name")
             if hasattr(self.data, "filename") and old == new:
                 self.cw_edited["data_name"] = self.data.filename
+
+            # If data has been changed, and not data_format nor data_encoding,
+            # we probably should recompute them.
+            for attr in ("data_format", "data_encoding"):
+                if attr not in self.cw_edited:
+                    continue
+
+                old, new = self.cw_edited.oldnewvalue(attr)
+                if old == new:
+                    self.cw_edited.pop(attr)
         else:
             self.cw_edited["data_format"] = None
             self.cw_edited["data_encoding"] = None
@@ -366,7 +375,7 @@ class IImageAdapter(EntityAdapter):
             raise UnResizeable
         data = idownloadable.download_data()
         pilimg = pilopen(Binary(data))
-        pilimg.thumbnail(size, ANTIALIAS)
+        pilimg.thumbnail(size)
         stream = Binary()
         pilimg.save(stream, fmt)
         stream.seek(0)
@@ -389,7 +398,7 @@ class IImageAdapter(EntityAdapter):
                 "and you should use css rules to lay shadows out",
                 DeprecationWarning,
             )
-        pilimg.thumbnail(size, ANTIALIAS)
+        pilimg.thumbnail(size)
         stream = Binary()
         pilimg.save(stream, "png")
         stream.seek(0)
