@@ -1,7 +1,7 @@
 """hash functions for the cubicbweb-file cube
 
 :organization: Logilab
-:copyright: 2018 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2018-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 
@@ -12,7 +12,7 @@ import hashlib
 def compute_hash(value, alg):
     hashvalue = compute_row_hash(value, alg)
     if hashvalue:
-        return '{%s}%s' % (alg, hashvalue)
+        return "{%s}%s" % (alg, hashvalue)
 
 
 def compute_row_hash(value, alg):
@@ -22,12 +22,12 @@ def compute_row_hash(value, alg):
 
 
 def check_hash(hash_value, value):
-    m = re.match('{(?P<alg>[A-Za-z0-9]+)}(?P<hash>.+)', hash_value)
+    m = re.match("{(?P<alg>[A-Za-z0-9]+)}(?P<hash>.+)", hash_value)
     if m:
-        alg = m.group('alg')
-        hashhex = m.group('hash')
+        alg = m.group("alg")
+        hashhex = m.group("hash")
     else:  # bw compat, used to be sha1
-        alg = 'sha1'
+        alg = "sha1"
         hashhex = hash_value
     comphash = compute_row_hash(value, alg=alg)
     return comphash == hashhex
