@@ -1,7 +1,7 @@
-from cubicweb.view import EntityView
+from cubicweb_web.view import EntityView
 from cubicweb.predicates import is_instance, one_line_rset, adaptable
-from cubicweb.web import formwidgets as wdgs
-from cubicweb.web.views import baseviews, uicfg, idownloadable
+from cubicweb_web import formwidgets as wdgs
+from cubicweb_web.views import baseviews, uicfg, idownloadable
 
 _pvs = uicfg.primaryview_section
 _pvs.tag_attribute(("File", "title"), "hidden")
