@@ -9,10 +9,10 @@ __docformat__ = "restructuredtext en"
 
 from logilab.mtconverter import xml_escape
 
-from cubicweb.view import EntityView
+from cubicweb_web.view import EntityView
 from cubicweb.predicates import is_instance, has_mimetype, adaptable
-from cubicweb.web.views import ajaxcontroller
-from cubicweb.web import NotFound
+from cubicweb_web.views import ajaxcontroller
+from cubicweb_web import NotFound
 
 
 class GalleryView(EntityView):
