@@ -3,10 +3,11 @@
 from os.path import join, dirname, isfile, exists
 import shutil
 
+from cubicweb.devtools import BASE_URL
 from cubicweb.devtools.testlib import CubicWebTC
 
 from cubicweb import NoSelectableObject, Binary, Unauthorized
-from cubicweb.web import NotFound
+from cubicweb_web import NotFound
 
 from cubicweb_file.entities import thumb_cache_dir
 
@@ -39,7 +40,7 @@ class FileTC(CubicWebTC):
             self.assertEqual(idownloadable.download_data(), b"xxx")
             self.assertEqual(
                 idownloadable.download_url(),
-                "http://testing.fr/cubicweb/%s/%s/raw/%s"
+                f"{BASE_URL}%s/%s/raw/%s"
                 % (fobj.__regid__.lower(), self.fobj, fobj.data_name),
             )
             self.assertEqual(idownloadable.download_content_type(), self.mime_type)
@@ -50,7 +51,7 @@ class FileTC(CubicWebTC):
             idownloadable = ufobj.cw_adapt_to("IDownloadable")
             self.assertEqual(
                 idownloadable.download_url(),
-                "http://testing.fr/cubicweb/%s/%s/raw/%s"
+                f"{BASE_URL}%s/%s/raw/%s"
                 % (
                     ufobj.__regid__.lower(),
                     self.ufobj,
@@ -62,9 +63,7 @@ class FileTC(CubicWebTC):
         with self.admin_access.web_request() as req:
             fobj = req.entity_from_eid(self.fobj)
             self.assertEqual(fobj.size(), 3)
-            self.assertEqual(
-                fobj.icon_url(), "http://testing.fr/cubicweb/data/icons/" + self.icon
-            )
+            self.assertEqual(fobj.icon_url(), f"{BASE_URL}data/icons/{self.icon}")
 
     def test_views(self):
         with self.admin_access.web_request() as req:
@@ -256,8 +255,7 @@ class ImageTC(CubicWebTC):
             # file content is (literally) "xxx"
             self.assertEqual(ithumb.thumbnail_data(), "")
             self.assertEqual(
-                "http://testing.fr/cubicweb/%s/%s/thumb/foo_75x75.png"
-                % (fobj.__regid__.lower(), self.fobj),
+                f"{BASE_URL}{fobj.__regid__.lower()}/{self.fobj}/thumb/foo_75x75.png",
                 ithumb.thumbnail_url(),
             )
 
@@ -270,8 +268,7 @@ class ImageTC(CubicWebTC):
             thumbadapter = img.cw_adapt_to("IThumbnail")
             self.assertEqual("20x20_75x75.png", thumbadapter.thumbnail_file_name())
             self.assertEqual(
-                "http://testing.fr/cubicweb/file/%s/thumb/20x20_75x75.png"
-                % img.eid,  # noqa
+                f"{BASE_URL}file/{img.eid}/thumb/20x20_75x75.png",  # noqa
                 thumbadapter.thumbnail_url(),
             )
             cachepath = thumbadapter._thumbnail_path()
