@@ -14,6 +14,33 @@ class FileTC(CubicWebTC):
             self.assertEqual(fobj.data_format, "text/plain")
             self.assertEqual(fobj.data_encoding, cnx.encoding)
 
+    def test_set_mime_and_encoding_after_data_changed(self):
+        with self.admin_access.client_cnx() as cnx:
+            fobj = cnx.create_entity("File", data_name="foo.txt", data=Binary(b"xxx"))
+            self.assertEqual(fobj.data_format, "text/plain")
+            self.assertEqual(fobj.data_encoding, cnx.encoding)
+
+            # Mimic a POST request, where all data a resend (name, binary and
+            # data_format) *and* data_format is not changed by the user. We want
+            # data_format to be reset and recomputed to image/jpeg
+            fobj.cw_set(
+                data_name="toto.jpg",
+                data=Binary(b"xxx"),
+                data_format=fobj.data_format,
+            )
+
+            self.assertEqual(fobj.data_format, "image/jpeg")
+
+            # If data_format is given, and different for the previous value, it
+            # should not be recomputed but directly used.
+            fobj.cw_set(
+                data_name="toto.my_extension",
+                data=Binary(b"xxx"),
+                data_format="application/my-application",
+            )
+
+            self.assertEqual(fobj.data_format, "application/my-application")
+
     def test_set_mime_and_encoding_gz_file(self):
         with self.admin_access.client_cnx() as cnx:
             fobj = cnx.create_entity(
